.codehilite {
    background: var(--neutral-fill-active);
}
.bk.card button.bk.card-header {
    height: 55px;
}
p.bk.card-button {
    display: block;
    padding-right: 1em;
}
.bk.card {
	color: var(--neutral-foreground-rest);
	background-color: var(--neutral-fill-rest);
  }
.bk.card-header {
	color: var(--neutral-foreground-rest);
	background-color: var(--neutral-fill-active) !important;
}