:root {
    --accent-fill-active: #C01754;
    --accent-fill-hover: #86103B;
    --accent-fill-rest: #A01346;
    --accent-foreground-active: #BA1651;
    --accent-foreground-cut-rest: #FFFFFF;
    --accent-foreground-hover: #7A0F35;
    --accent-foreground-rest: #A01346;
    --background-color: #F7F7F7;
    /* --container-background: #D1D1D1;
    --neutral-divider-rest:#838383; */
    --neutral-fill-active: #EAEAEA;
    --neutral-fill-hover: #DDDDDD;
    --neutral-fill-input-active: #FFFFFF;
    --neutral-fill-input-hover: #FFFFFF;
    --neutral-fill-input-rest: #FFFFFF;
    --neutral-fill-rest: #E5E5E5;
    --neutral-fill-stealth-active: #EFEFEF;
    --neutral-fill-stealth-hover: #EAEAEA;
    --neutral-fill-stealth-rest: #F7F7F7;
    --neutral-focus: #838383;
    --neutral-focus-inner-accent: #FFFFFF;
    --neutral-foreground-active: #2B2B2B;
    --neutral-foreground-focus: #2B2B2B;
    --neutral-foreground-hover: #2B2B2B;
    --neutral-foreground-rest: #262626;
    --neutral-layer-floating: #FFFFFF;
    --neutral-outline-active: #D6D6D6;
    --neutral-outline-hover: #979797;
    --neutral-outline-rest: #BEBEBE;
    --outline-width: 1;
    --track-width: 2;
    --type-ramp-base-font-size: 14px;
    --type-ramp-base-line-height: 20px;
    --type-ramp-minus-1-font-size: 12px;
    --type-ramp-minus-1-line-height: 16px;
    --type-ramp-minus-2-font-size: 10px;
    --type-ramp-minus-2-line-height: 16px;
    --type-ramp-plus-1-font-size: 16px;
    --type-ramp-plus-1-line-height: 24px;
    --type-ramp-plus-2-font-size: 20px;
    --type-ramp-plus-2-line-height: 28px;
    --type-ramp-plus-3-font-size: 28px;
    --type-ramp-plus-3-line-height: 36px;
    --type-ramp-plus-4-font-size: 34px;
    --type-ramp-plus-4-line-height: 44px;
    --type-ramp-plus-5-font-size: 46px;
    --type-ramp-plus-5-line-height: 56px;
    --type-ramp-plus-6-font-size: 60px;
    --type-ramp-plus-6-line-height: 72px;
}